
/*
 * Table
 */
table.dataTable {
  margin: 0 auto;
  clear: both;
  width: 100%;
}

table.dataTable thead th {
  padding: 3px 10px 3px 18px;
  border-bottom: 1px solid black;
  font-weight: bold;
  cursor: pointer;
  *cursor: hand;
}

table.dataTable tfoot th {
  padding: 3px 18px 3px 10px;
  border-top: 1px solid black;
  font-weight: bold;
}

table.dataTable td {
  padding: 3px 10px;
}

table.dataTable td.center,
table.dataTable td.dataTables_empty {
  text-align: center;
}

/*table.dataTable tr.odd { background-color: #F5F5F5; }
table.dataTable tr.even { background-color: #FCFCFC; }

table.dataTable tr.odd td.sorting_1 { background-color: #F5F5F5; }
table.dataTable tr.odd td.sorting_2 { background-color: #F5F5F5; }
table.dataTable tr.odd td.sorting_3 { background-color: #F5F5F5; }
table.dataTable tr.even td.sorting_1 { background-color: #FCFCFC; }
table.dataTable tr.even td.sorting_2 { background-color: #FCFCFC; }
table.dataTable tr.even td.sorting_3 { background-color: #FCFCFC; }
*/

/*
 * Table wrapper
 */
.dataTables_wrapper {
  position: relative;
  clear: both;
  *zoom: 1;
}


/*
 * Page length menu
 */
.dataTables_length {
  float: left;
  font-style: italic;
  line-height: 1.8;
}


/*
 * Filter
 */
.dataTables_filter {
  float: right;
  line-height: 1.8;
  text-align: right;
  text-align: right;
}


/*
 * Table information
 */
.dataTables_info {
  clear: both;
  float: left;
}


/*
 * Pagination
 */
.dataTables_paginate {
  float: right;
  text-align: right;
}

/* Two button pagination - previous / next */
.paginate_button_enabled {
  height: 19px;
  float: left;
  color: #111 !important;
}
.not(.paginate_button_disabled):hover {
  cursor: pointer;
  *cursor: hand;
  text-decoration: none !important;
}
.paginate_button_enabled:active {
  outline: none;
}

.paginate_disabled_previous,
.paginate_disabled_next {
  color: #666 !important;
}
.paginate_disabled_previous,
.paginate_enabled_previous {
  padding-left: 23px;
}
.paginate_disabled_next,
.paginate_enabled_next {
  padding-right: 23px;
  margin-left: 10px;
}

.first.paginate_button.:not(.paginate_button_disabled) { background: url('images/first_enabled.png') no-repeat top left; }
.first.paginate_button.:not(.paginate_button_disabled):hover { background: url('images/first_enabled_hover.png') no-repeat top left; }
.first.paginate_button { background: url('images/first_disabled.png') no-repeat top left; }

.previous.paginate_button.:not(.paginate_button_disabled) { background: url('images/back_enabled.png') no-repeat top left; }
.previous.paginate_button.:not(.paginate_button_disabled):hover { background: url('images/back_enabled_hover.png') no-repeat top left; }
.previous.paginate_button { background: url('images/back_disabled.png') no-repeat top left; }

.next.paginate_button.:not(.paginate_button_disabled)  { background: url('images/forward_enabled.png') no-repeat top right; }
.next.paginate_button.:not(.paginate_button_disabled):hover { background: url('images/forward_enabled_hover.png') no-repeat top right; }
.next.paginate_button { background: url('images/forward_disabled.png') no-repeat top right; }

.last.paginate_button.:not(.paginate_button_disabled)  { background: url('images/last_enabled.png') no-repeat top right; }
.last.paginate_button.:not(.paginate_button_disabled):hover { background: url('images/last_enabled_hover.png') no-repeat top right; }
.last.paginate_button { background: url('images/last_disabled.png') no-repeat top right; }

/* Full number pagination */
.paging_full_numbers {
  height: 22px;
  line-height: 22px;
}
.paging_full_numbers a:active {
  outline: none
}
.paging_full_numbers a:hover {
  text-decoration: none;
}

.paging_full_numbers a.paginate_button,
.paging_full_numbers a.paginate_active {
  border: 1px solid #aaa;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  padding: 2px 5px;
  margin: 0 3px;
  cursor: pointer;
  *cursor: hand;
  color: #333 !important;
}

.paging_full_numbers a.paginate_button {
  background-color: #ddd;
}

.paging_full_numbers a.paginate_button:hover {
  background-color: #ccc;
  text-decoration: none !important;
}

.paging_full_numbers a.paginate_active {
  background-color: #99B3FF;
}

/*
 * Processing indicator
 */
.dataTables_processing {
  position: absolute;
  top: 50%;
  left: 50%;
  width: 250px;
  height: 30px;
  margin-left: -125px;
  margin-top: -15px;
  padding: 14px 0 2px 0;
  border: 1px solid #ddd;
  text-align: center;
  color: #999;
  font-size: 14px;
  background-color: white;
}


/*
 * Sorting
 */
.sorting { background: url('images/sort_both.png') no-repeat center left; }
.sorting_asc { background: url('images/sort_asc.png') no-repeat center left; }
.sorting_desc { background: url('images/sort_desc.png') no-repeat center left; }

.sorting_asc_disabled { background: url('images/sort_asc_disabled.png') no-repeat center left; }
.sorting_desc_disabled { background: url('images/sort_desc_disabled.png') no-repeat center left; }
 
table.dataTable thead th:active,
table.dataTable thead td:active {
  outline: none;
}


/*
 * Scrolling
 */
.dataTables_scroll {
  clear: both;
}

.dataTables_scrollBody {
  *margin-top: -1px;
  -webkit-overflow-scrolling: touch;
}

div.clear {
  clear: both;
}

