h1 a {
  text-decoration: none;
}
div#main {
  clear: both;
  vertical-align: top;
  margin: 0 10px;
  margin-top: 60px;
}
/*
 * LOGIN / ACCUEIL
 */
nav#menupal {
  margin-top: 40px;
  text-align: center;
}
nav#menupal img#barre_cwk {
  margin-bottom: 0px;
}
nav#menupal a img:hover {
  height: 120px;
}
/*
 * GRID TABLE PART
 */
span#table_limit_warn {
  color: #fe352b;
}
table.datatable {
  border-collapse: collapse;
  font-size: 13px;
  width: 100%;
}
table.datatable caption {
  text-align: left;
  color: #AABBB5;
  border-left: 1px solid black;
  border-bottom: 1px solid black;
  padding-left: 10px;
  margin-bottom: 5px;
}
table.datatable thead {
  background-color: #E4EFF6;
  -moz-user-select: none;
  -webkit-user-select: none;
  -ms-user-select: none;
  cursor: default;
}
table.datatable thead th {
  color: #4d70a8;
  border-bottom: 1px dotted #4d79a8;
}
table.datatable tbody tr:nth-child(even) {
  background-color: #F5F5F5;
}
table.datatable tbody tr:hover {
  background-color: #A8DD93;
}
table.datatable tbody tr.selected {
  background-color: #D7FAC9;
}
table.datatable td,
table.datatable th {
  padding-left: 15px;
  padding-right: 15px;
  text-align: left;
  overflow: hidden;
  vertical-align: middle;
}
table.datatable span.info {
  background-image: url('/shared/css/images/tooltip.png');
  display: inline-block;
  width: 16px;
}
