{% extends 'studiogdo/pip/base.html' %}

{% load staticfiles %}

{% block body %}
    <div id="main" style="margin-top: 30px;">
        <nav id="menupal">
            <br>{% block logo %}{% endblock %}<br>
        </nav>
        <h1 class="text-center" style="margin:40px 0">{% block h1_title %}Portail Internet Personnalisé{% endblock %}</h1>

        <form method="post" class="form-horizontal">{% csrf_token %}
            {% if error_msg %}
                <div class="text-center">
                    <span class="alert alert-danger">{{ error_msg }}</span>
                </div>
            {% endif %}
            <div class="container" style="width:280px;">
                <div class="form-group">
                    <label for="username" class="col-md-5 control-label">Utilisateur</label>
                    <div class="col-md-7">
                        <input id="username" type="text" name="username" tabindex="1" class="form-control">
                    </div>
                </div>
                <div class="form-group  has-feedback">
                    <label for="password" class="col-md-5 control-label">Mot de passe</label>

                    <div class="col-md-7">
                        <input id="password" class="form-control" type="password" name="password" tabindex="2">
                    <span id="alertMaj" class="glyphicon glyphicon-warning-sign form-control-feedback"
                          title="Attention saisie en MAJUSCULE" style="display:none;"></span>
                    </div>
                </div>
                <button id="login" class="btn btn-primary pull-right" tabindex="3">
                    Connexion
                </button>
            </div>
        </form>
        <div style="position: fixed;top: 10px;right: 10px;">
            <img src="{% static 'studiogdo/pip/img/django-studiogdo.jpg' %}" alt="powered">
        </div>
    </div>
{% endblock body %}

{% block coffee %}
    require(['pip/login'], function() {
    });
{% endblock coffee %}
