{% extends 'studiogdo/pip/base.html' %}

{% load staticfiles %}
{% load studiogdo %}

{% block body %}
    <div id="waiting_page"></div>

    <nav class="navbar navbar-default navbar-fixed-top" role="navigation">
        <div class="container-fluid">
            <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
                {% include 'pip/menu.html' %}
                {% skel 'studiogdo/pip/menu_top_right.skel' '/Session' %}
            </div>
        </div>
    </nav>

    {% block main %}
    <div id="main" class="container-fluid">
        {% block main_content %}{% endblock main_content %}
    </div>
    {% endblock main %}

    {% block modals %}{% endblock modals %}

{% endblock body %}

{% block coffee %}
{% endblock coffee %}
