{% extends 'studiogdo/pip/main_base.html' %}

{% load studiogdo %}

{% block main_content %}
    {% block before_skel %}{% endblock before_skel %}
    <div class="row">
        <div class="col-sm-12">
            {% skel skel.0 data_path %}
        </div>
    </div>
    {% block after_skel %}{% endblock after_skel %}
{% endblock main_content %}

{% block coffee %}
require(['pip/list'], function(List) {
    new List()
});
{% endblock coffee %}
