{% load staticfiles %}

<html lang="fr">
<head>
    {% block head %}
        <meta charset="utf-8">
        <META HTTP-EQUIV="CACHE-CONTROL" CONTENT="NO-CACHE">
        <title>{% block title %}Portail Internet Personnalisé{% endblock %}</title>
        {% block css %}
            <link rel="stylesheet" href="{% static 'studiogdo/pip/css/jquery.dataTables.css' %}" type="text/css"/>
            <link rel="stylesheet" href="{% static 'studiogdo/pip/css/glyphicons.css' %}" type="text/css"/>
            <link rel="stylesheet" href="{% static 'studiogdo/pip/css/bootstrap.min.css' %}" type="text/css"/>
            <link rel="stylesheet" href="{% static 'studiogdo/pip/css/bootstrap-datetimepicker.min.css' %}" type="text/css"/>
            <link rel="stylesheet" href="{% static 'studiogdo/pip/css/fullcalendar/fullcalendar.css' %}" type="text/css" />
            <link rel="stylesheet" href="{% static 'studiogdo/pip/css/stylesheet.css' %}" type="text/css"/>
            <link rel="stylesheet" href="{% static 'css/stylesheet.css' %}" type="text/css"/>
        {% endblock css %}
        {% block js %}
            <script type="text/javascript" src="{% url 'javascript_catalog' %}"></script>
            <script src="{% static 'studiogdo/pip/js/jquery.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/jquery.dataTables.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/jquery.blinker.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/bootstrap.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/moment/moment.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/fullcalendar/fullcalendar.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/numeral/numeral.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/numeral/languages.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/numeral/languages/fr.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/bootstrap-datetimepicker.min.js' %}"></script>
            {# <script src="{% static 'studiogdo/pip/js/datepicker/locales/bootstrap-datepicker.fr.js' %}"></script> #}
            <script src="{% static 'studiogdo/pip/js/requirejs.js' %}"></script>
            <script src="{% static 'studiogdo/js/studiogdo.js' %}"></script>
            <script src="{% static 'studiogdo/js/serializeForm.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/tinymce/tinymce.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/tinymce/jquery.tinymce.min.js' %}"></script>
            <script src="{% static 'studiogdo/pip/js/tinymce/langs/fr_FR.min.js' %}"></script>
        {% endblock js %}
    {% endblock %}
</head>
<body>
{% block wait %}<img id="wait" src="{% static 'common/img/wait.gif' %}" style="display:none; position:fixed; left:50%; top:195px;z-index:1000;">{% endblock wait %}
{% block body %}{% endblock body %}
<script>
    $(function () {
        requirejs.config({
            skipDataMain: true,
            baseUrl: "{% static 'js' %}",
            paths: {
                studiogdo: "{% static 'studiogdo/js' %}",
                list: "{% static 'studiogdo/js/list' %}",
                pip: "{% static 'studiogdo/pip/js' %}",
                common: "{% static 'common/js' %}"
            }
        });

        BOCall.rootAddress = "{% url 'studiogdo' %}";
        BOCall.loginAddress = "{% url 'login' %}";

        require(['pip/main'], function (Main) {
            new Main()
        });
        {% block coffee %}{% endblock coffee %}
    });
</script>
{% include 'studiogdo/pip/tracking/all.html' %}
</body>
</html>
